@@ -1,5 +1,5 @@
 import json
-from typing import Type, cast
+from typing import Mapping, Type, cast
 
 from event_sourcery.dto.raw_event_dict import RawEventDict
 from event_sourcery.interfaces.event import Event
@@ -11,7 +11,7 @@ from event_sourcery_pydantic.event import Event as PydanticEvent
 class PydanticSerde(Serde):
     def deserialize(self, event: RawEventDict, event_type: Type[Event]) -> Event:
         event_as_dict = dict(event)
-        data = event_as_dict.pop("data")
+        data = cast(Mapping, event_as_dict.pop("data"))
         return cast(Event, event_type(**event_as_dict, **data))
 
     def serialize(self, event: Event, stream_id: StreamId, name: str) -> RawEventDict:
